@@ -1,5 +1,4 @@
 """A10 support."""
-from __future__ import unicode_literals
 import time
 from netmiko.cisco_base_connection import CiscoSSHConnection
 
@@ -12,10 +11,10 @@ class A10SSH(CiscoSSHConnection):
         self._test_channel_read()
         self.set_base_prompt()
         self.enable()
-        self.disable_paging(command="terminal length 0")
 
         # Will not do anything without A10 specific command
-        self.set_terminal_width()
+        # self.set_terminal_width()
+        self.disable_paging(command="terminal length 0")
 
         # Clear the read buffer
         time.sleep(0.3 * self.global_delay_factor)
